@@ -243,12 +243,12 @@ class Action:
     def __eq__(self, other):
         if self is other:
             return True
-        elif not isinstance(other, type(self)):
+        if not isinstance(other, type(self)):
             return False
-        elif self.target != other.target:
+        if self.target != other.target:
             return False
-        elif not (math.isclose(self.cost, other.cost)
-                  and math.isclose(self.prob, other.prob)):
+        if not (math.isclose(self.cost, other.cost)
+                and math.isclose(self.prob, other.prob)):
             return False
         return self.req_access == other.req_access
 
@@ -568,6 +568,11 @@ class ActionResult:
     permission_error : bool
         True if action failed due to a permission error (e.g. incorrect access
         level to perform action)
+    undefined_error : bool
+        True if action failed due to an undefined error (e.g. random exploit
+        failure)
+    newly_discovered : dict
+        host addresses discovered for the first time by action
     """
 
     def __init__(self,
@@ -579,7 +584,9 @@ class ActionResult:
                  access=None,
                  discovered=None,
                  connection_error=False,
-                 permission_error=False):
+                 permission_error=False,
+                 undefined_error=False,
+                 newly_discovered=None):
         """
         Parameters
         ----------
@@ -588,19 +595,23 @@ class ActionResult:
         value : float, optional
             value gained from action (default=0.0)
         services : dict, optional
-            services identified by action (default=None)
+            services identified by action (default=None={})
         os : dict, optional
-            OS identified by action (default=None)
+            OS identified by action (default=None={})
         processes : dict, optional
-            processes identified by action (default=None)
+            processes identified by action (default=None={})
         access : dict, optional
-            access gained by action (default=None)
+            access gained by action (default=None={})
         discovered : dict, optional
-            host addresses discovered by action (default=None)
+            host addresses discovered by action (default=None={})
         connection_error : bool, optional
-            True if action failed due to connection error (default=None)
+            True if action failed due to connection error (default=False)
         permission_error : bool, optional
-            True if action failed due to a permission error (default=None)
+            True if action failed due to a permission error (default=False)
+        undefined_error : bool, optional
+            True if action failed due to an undefined error (default=False)
+        newly_discovered : dict, optional
+            host addresses discovered for first time by action (default=None)
         """
         self.success = success
         self.value = value
@@ -611,6 +622,11 @@ class ActionResult:
         self.discovered = {} if discovered is None else discovered
         self.connection_error = connection_error
         self.permission_error = permission_error
+        self.undefined_error = undefined_error
+        if newly_discovered is not None:
+            self.newly_discovered = newly_discovered
+        else:
+            self.newly_discovered = {}
 
     def info(self):
         """Get results as dict
@@ -629,13 +645,14 @@ class ActionResult:
             access=self.access,
             discovered=self.discovered,
             connection_error=self.connection_error,
-            permission_error=self.permission_error
+            permission_error=self.permission_error,
+            newly_discovered=self.newly_discovered
         )
 
     def __str__(self):
-        output = ["ActionObservation:"],
-        for k, v in self.info().items():
-            output.append(f"  {k}={v}")
+        output = ["ActionObservation:"]
+        for k, val in self.info().items():
+            output.append(f"  {k}={val}")
         return "\n".join(output)
 
 
@@ -692,25 +709,37 @@ class ParameterisedActionSpace(spaces.MultiDiscrete):
     The action parameters (in order) are:
 
     0. Action Type = [0, 5]
-       where:
-          0=Exploit,
-          1=PrivilegeEscalation,
-          2=ServiceScan,
-          3=OSScan,
-          4=SubnetScan,
-          5=ProcessScan,
+
+       Where:
+
+         0=Exploit,
+
+         1=PrivilegeEscalation,
+
+         2=ServiceScan,
+
+         3=OSScan,
+
+         4=SubnetScan,
+
+         5=ProcessScan,
+
     1. Subnet = [0, #subnets-1]
+
        -1 since we don't include the internet subnet
+
     2. Host = [0, max subnets size-1]
     3. OS = [0, #OS+1]
-       Where 0=None.
-       Note, this is only important for exploits and privilege escalation.
-    4. Service = [0, #services]
-       Note, this is only important for exploits
-    5. Process = [0, #processes+1]
-       Where 0=None
-       Note, this is only important for privilege escalation
 
+       Where 0=None.
+
+    4. Service = [0, #services]
+    5. Process = [0, #processes+1]
+
+       Where 0=None.
+
+    Note that OS, Service and Process are only importand for exploits and
+    privilege escalation actions.
 
     ...
 
@@ -784,7 +813,7 @@ class ParameterisedActionSpace(spaces.MultiDiscrete):
 
         target = (subnet, host)
 
-        if not (a_class == Exploit or a_class == PrivilegeEscalation):
+        if a_class not in (Exploit, PrivilegeEscalation):
             # can ignore other action parameters
             kwargs = self._get_scan_action_def(a_class)
             return a_class(target=target, **kwargs)
@@ -810,15 +839,16 @@ class ParameterisedActionSpace(spaces.MultiDiscrete):
     def _get_scan_action_def(self, a_class):
         """Get the constants for scan actions definitions """
         if a_class == ServiceScan:
-            return {"cost": self.scenario.service_scan_cost}
+            cost = self.scenario.service_scan_cost
         elif a_class == OSScan:
-            return {"cost": self.scenario.os_scan_cost}
+            cost = self.scenario.os_scan_cost
         elif a_class == SubnetScan:
-            return {"cost": self.scenario.subnet_scan_cost}
+            cost = self.scenario.subnet_scan_cost
         elif a_class == ProcessScan:
-            return {"cost": self.scenario.process_scan_cost}
+            cost = self.scenario.process_scan_cost
         else:
             raise TypeError(f"Not implemented for Action class {a_class}")
+        return {"cost": cost}
 
     def _get_exploit_def(self, service, os):
         """Check if exploit parameters are valid """
