@@ -1,7 +1,8 @@
+"""This module contains functions and classes for rendering NASim """
 import math
 import random
-import networkx as nx
 import tkinter as Tk
+import networkx as nx
 from prettytable import PrettyTable
 
 # import order important here
@@ -419,7 +420,7 @@ class EpisodeViewer:
                 f"t={self.timestep}\nGoal reached\ntotal reward={reward}"
             )
         else:
-            title = "t={self.timestep}\n{action}\nreward={reward}"
+            title = f"t={self.timestep}\n{action}\nreward={reward}"
         ax_title = self.axes.set_title(title, fontsize=16, pad=10)
         ax_title.set_y(1.05)
 
